pub struct Buffer { /* private fields */ }Expand description
A Luau buffer type.
See the buffer documentation for more information.
Mirrors mlua::Buffer. Holds a registry reference keeping the buffer alive.
Under the send feature it is Send but never Sync — see
[crate::sync::NotSync].
Implementations
Sourceimpl Buffer
impl Buffer
Sourcepub fn to_vec(&self) -> Vec<u8> ⓘ
pub fn to_vec(&self) -> Vec<u8> ⓘ
Copies the buffer data into a new Vec<u8>.
Mirrors mlua::Buffer::to_vec.
Sourcepub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> bool
Returns true if the buffer is empty.
Mirrors mlua::Buffer::is_empty.
Sourcepub fn read_bytes<const N: usize>(&self, offset: usize) -> [u8; N]
pub fn read_bytes<const N: usize>(&self, offset: usize) -> [u8; N]
Reads given number of bytes from the buffer at the given offset.
Offset is 0-based.
Mirrors mlua::Buffer::read_bytes.
Sourcepub fn write_bytes(&self, offset: usize, bytes: &[u8])
pub fn write_bytes(&self, offset: usize, bytes: &[u8])
Writes given bytes to the buffer at the given offset.
Offset is 0-based.
Mirrors mlua::Buffer::write_bytes.