IntoLuaMulti

Trait IntoLuaMulti 

pub trait IntoLuaMulti: Sized {
    // Required method
    fn into_lua_multi(self, lua: &Lua) -> Result<MultiValue>;
}
Convert a Rust value into a sequence of Lua values (multiple returns / args).

Mirrors mlua::IntoLuaMulti.

Required Methods

fn into_lua_multi(self, lua: &Lua) -> Result<MultiValue>

Perform the conversion.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl IntoLuaMulti for ()

Source

impl<A: IntoLuaMulti, B: IntoLuaMulti, C: IntoLuaMulti, D: IntoLuaMulti, E: IntoLuaMulti, F: IntoLuaMulti, G: IntoLuaMulti, H: IntoLuaMulti, I: IntoLuaMulti, J: IntoLuaMulti, K: IntoLuaMulti, L: IntoLuaMulti> IntoLuaMulti for (A, B, C, D, E, F, G, H, I, J, K, L)

Source

impl<B: IntoLuaMulti, C: IntoLuaMulti, D: IntoLuaMulti, E: IntoLuaMulti, F: IntoLuaMulti, G: IntoLuaMulti, H: IntoLuaMulti, I: IntoLuaMulti, J: IntoLuaMulti, K: IntoLuaMulti, L: IntoLuaMulti> IntoLuaMulti for (B, C, D, E, F, G, H, I, J, K, L)

Source

impl<C: IntoLuaMulti, D: IntoLuaMulti, E: IntoLuaMulti, F: IntoLuaMulti, G: IntoLuaMulti, H: IntoLuaMulti, I: IntoLuaMulti, J: IntoLuaMulti, K: IntoLuaMulti, L: IntoLuaMulti> IntoLuaMulti for (C, D, E, F, G, H, I, J, K, L)

Source

impl<D: IntoLuaMulti, E: IntoLuaMulti, F: IntoLuaMulti, G: IntoLuaMulti, H: IntoLuaMulti, I: IntoLuaMulti, J: IntoLuaMulti, K: IntoLuaMulti, L: IntoLuaMulti> IntoLuaMulti for (D, E, F, G, H, I, J, K, L)

Source

impl<E: IntoLuaMulti, F: IntoLuaMulti, G: IntoLuaMulti, H: IntoLuaMulti, I: IntoLuaMulti, J: IntoLuaMulti, K: IntoLuaMulti, L: IntoLuaMulti> IntoLuaMulti for (E, F, G, H, I, J, K, L)

Source

impl<F: IntoLuaMulti, G: IntoLuaMulti, H: IntoLuaMulti, I: IntoLuaMulti, J: IntoLuaMulti, K: IntoLuaMulti, L: IntoLuaMulti> IntoLuaMulti for (F, G, H, I, J, K, L)

Source

impl<G: IntoLuaMulti, H: IntoLuaMulti, I: IntoLuaMulti, J: IntoLuaMulti, K: IntoLuaMulti, L: IntoLuaMulti> IntoLuaMulti for (G, H, I, J, K, L)

Source

impl<H: IntoLuaMulti, I: IntoLuaMulti, J: IntoLuaMulti, K: IntoLuaMulti, L: IntoLuaMulti> IntoLuaMulti for (H, I, J, K, L)

Source

impl<I: IntoLuaMulti, J: IntoLuaMulti, K: IntoLuaMulti, L: IntoLuaMulti> IntoLuaMulti for (I, J, K, L)

Source

impl<J: IntoLuaMulti, K: IntoLuaMulti, L: IntoLuaMulti> IntoLuaMulti for (J, K, L)

Source

impl<K: IntoLuaMulti, L: IntoLuaMulti> IntoLuaMulti for (K, L)

Source

impl<L: IntoLuaMulti> IntoLuaMulti for (L,)

Source

impl<T: IntoLuaMulti, E: IntoLua> IntoLuaMulti for Result<T, E>

Result<T, E> spreads as the success values on Ok, or as (nil, error) on Err — mirroring mlua’s IntoLuaMulti for Result.

Implementors